@@ -37,10 +37,8 @@ class CommittedFileSizeCheck(CommittedFileCheck):
 
     def get_problems(self):
         file_size = self.committed_file.get_file_size()
-        extension = self.committed_file.get_extension()
+        extension = self.committed_file.get_extension().replace('"', "").replace("'", "")
         is_framework = self.committed_file.get_framework()
-        path = self.committed_file.get_path()
-        print(f"extension: {extension}\nis_framework: {is_framework}\npath: {path}")
         if file_size == -1:
             yield (
                 Severity.ERROR,
